==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkGraphHierarchicalBundleEdges.java <==
// java wrapper for vtkGraphHierarchicalBundleEdges object
//

package vtk;
import vtk.*;

public class vtkGraphHierarchicalBundleEdges extends vtkGraphAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBundlingStrength_2(double id0);
  public void SetBundlingStrength(double id0)
    { SetBundlingStrength_2(id0); }

  private native double GetBundlingStrengthMinValue_3();
  public double GetBundlingStrengthMinValue()
    { return GetBundlingStrengthMinValue_3(); }

  private native double GetBundlingStrengthMaxValue_4();
  public double GetBundlingStrengthMaxValue()
    { return GetBundlingStrengthMaxValue_4(); }

  private native double GetBundlingStrength_5();
  public double GetBundlingStrength()
    { return GetBundlingStrength_5(); }

  private native void SetDirectMapping_6(boolean id0);
  public void SetDirectMapping(boolean id0)
    { SetDirectMapping_6(id0); }

  private native boolean GetDirectMapping_7();
  public boolean GetDirectMapping()
    { return GetDirectMapping_7(); }

  private native void DirectMappingOn_8();
  public void DirectMappingOn()
    { DirectMappingOn_8(); }

  private native void DirectMappingOff_9();
  public void DirectMappingOff()
    { DirectMappingOff_9(); }

  private native int FillInputPortInformation_10(int id0,vtkInformation id1);
  public int FillInputPortInformation(int id0,vtkInformation id1)
    { return FillInputPortInformation_10(id0,id1); }

  public vtkGraphHierarchicalBundleEdges() { super(); }

  public vtkGraphHierarchicalBundleEdges(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-1-aarch64.pkg.tar.xz: vtk/vtkGraphHierarchicalBundleEdges.java <==
// java wrapper for vtkGraphHierarchicalBundleEdges object
//

package vtk;
import vtk.*;

public class vtkGraphHierarchicalBundleEdges extends vtkGraphAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBundlingStrength_2(double id0);
  public void SetBundlingStrength(double id0)
    { SetBundlingStrength_2(id0); }

  private native double GetBundlingStrengthMinValue_3();
  public double GetBundlingStrengthMinValue()
    { return GetBundlingStrengthMinValue_3(); }

  private native double GetBundlingStrengthMaxValue_4();
  public double GetBundlingStrengthMaxValue()
    { return GetBundlingStrengthMaxValue_4(); }

  private native double GetBundlingStrength_5();
  public double GetBundlingStrength()
    { return GetBundlingStrength_5(); }

  private native void SetDirectMapping_6(boolean id0);
  public void SetDirectMapping(boolean id0)
    { SetDirectMapping_6(id0); }

  private native boolean GetDirectMapping_7();
  public boolean GetDirectMapping()
    { return GetDirectMapping_7(); }

  private native void DirectMappingOn_8();
  public void DirectMappingOn()
    { DirectMappingOn_8(); }

  private native void DirectMappingOff_9();
  public void DirectMappingOff()
    { DirectMappingOff_9(); }

  private native int FillInputPortInformation_10(int id0,vtkInformation id1);
  public int FillInputPortInformation(int id0,vtkInformation id1)
    { return FillInputPortInformation_10(id0,id1); }

  public vtkGraphHierarchicalBundleEdges() { super(); }

  public vtkGraphHierarchicalBundleEdges(long id) { super(id); }
  public native long   VTKInit();

}
